@@ -8,9 +8,10 @@ from django.utils.translation import ugettext_lazy as _
 from django.contrib.auth.models import User,Group
 from django.contrib.sites.models import Site
 from django.core.files.storage import FileSystemStorage
+import os
 
 # Create your models here.
-fs = FileSystemStorage(location='/usr/share/radioweb/static/media/audio')
+fs = FileSystemStorage(location=os.path.join(os.getcwd(), '/static/media/audio'))
 
 def get_rel(song,tags):
     relatedtags = set()
