@@ -8,13 +8,14 @@ Replace these with more appropriate tests for your application.
 from django.test import TestCase
 from django.test.client import Client
 from django.http import Http404
-
+import os
 
 from liquidjango.models import *
 from liquidjango.index import *
 from liquidjango.views import *
 from liquidjango.utils import *
 
+CURPATH = os.path.dirname(os.path.abspath(__file__))
 
 class SimpleTest(TestCase):
     def test_basic_addition(self):
@@ -24,15 +25,12 @@ class SimpleTest(TestCase):
         self.failUnlessEqual(1 + 1, 2)
 
 class LiquidsoapTest(TestCase):
-    
     def setUp(self):
         import telnetlib
         from django.conf import settings
         self.c = Client()
 
-
     def test_connection(self):
-
         tn = telnetlib.Telnet(settings.LIQ_HOST,port=settings.LIQ_PORT)
         self.assertTrue(tn.host==settings.LIQ_HOST)
         logging.info(u'test telnet connection:  host: %s' % tn.host)
@@ -56,18 +54,10 @@ class LiquidsoapTest(TestCase):
         self.assertTrue("skip': 'true', 'title': '', 'filename':" in str(nextsongs))
         self.failUnlessEqual(takeout, 'OK\n')
 
-    
-
 # here i should call a method for check if the file 
 # is in queue, but it's still not written....
 
-
-
-
-
-
 class FileImportTest(TestCase):
-
     def setUp(self):
         self.path = '/usr/share/radio/music/nerd/Supernerd.ogg'
 
@@ -75,19 +65,18 @@ class FileImportTest(TestCase):
         self.newsong = import_audio_from_archive(self.path)
         self.assertTrue(self.newsong.title == 'Supernerd')
 
-
         logging.info(u'song created: %(song)s, with id %(id)d' % \
                      { 'song': self.newsong.title, 'id': self.newsong.id} )
         self.assertTrue(self.newsong.artist.name == 'Paolo e chiarO')
 
     def test_channel_validation(self):
-        path = '/usr/share/radioweb/radio/fixtures/mono_file.ogg'
+        path = os.path.join(CURPATH, 'fixtures/mono_file.ogg')
         newsong = import_audio_from_archive(path)
         self.assertFalse(newsong == None)
         logging.info(u'test_channel_validation new song imported: %s' % newsong)
 
     def test_artist_tag(self):
-        path = '/usr/share/radioweb/radio/fixtures/artist_tag_missing.ogg'
+        path = os.path.join(CURPATH, 'fixtures/artist_tag_missing.ogg')
         newsong = import_audio_from_archive(path)
         #logging.info(u'new song: %s' % newsong)
         self.assertTrue( 'artist tag missing' in newsong )
@@ -98,9 +87,9 @@ class WebTest(TestCase):
     from django.test import client
 
     def setUp(self):
-        self.files = ['/usr/share/radioweb/radio/fixtures/Amiri_Baraka-Dope.ogg',
-                      '/usr/share/radioweb/radio/fixtures/mono_file.ogg',
-                      '/usr/share/radioweb/radio/fixtures/genre_tag_missing.ogg']
+        self.files = [os.path.join(CURPATH, 'fixtures/Amiri_Baraka-Dope.ogg'),
+                      os.path.join(CURPATH, 'fixtures/mono_file.ogg'),
+                      os.path.join(CURPATH, 'fixtures/genre_tag_missing.ogg')]
         self.c = Client()
         self.c.login(username='test',password='test')
 
@@ -162,7 +151,6 @@ class WebTest(TestCase):
 
     def test_homepage(self):
         '''opening the homepage'''
-
         response = self.c.get('/')
         self.assertTrue('artists' in  response.content)
         self.failUnlessEqual(response.status_code, 200)
@@ -171,7 +159,7 @@ class WebTest(TestCase):
     def test_import_and_add_tag(self):
 
         logging.info('importing songs')
-        folder = '/usr/share/radioweb/radio/fixtures/'
+        folder = os.path.join(CURPATH, 'fixtures/')
         newsongs = import_songs_from_folder(folder)
 
         logging.info('new songs: ')
@@ -247,7 +235,7 @@ class WebTest(TestCase):
         self.assertTrue('tag' in  response.content)
 
     def test_drop_page_error_messages(self):
-        f = open('/usr/share/radioweb/radio/fixtures/genre_tag_missing.ogg')
+        f = open(os.path.join(CURPATH, 'fixtures/genre_tag_missing.ogg'))
         response = self.c.post('/drop', { 'file': f, 'accept': True,
                             'csrfmiddlewaretoken': '02b2f45d81d9b6e0ba3e1e0fc02aa9ba'
                                          }) 
@@ -257,7 +245,7 @@ class WebTest(TestCase):
         f.close()
 
     def test_drop_an_audio_success(self):
-        f = open('/usr/share/radioweb/radio/fixtures/Amiri_Baraka-Dope.ogg')
+        f = open(os.path.join(CURPATH, 'fixtures/Amiri_Baraka-Dope.ogg'))
         response = self.c.post('/drop', { 'file': f, 'accept': True,
                     'csrfmiddlewaretoken':'02b2f45d81d9b6e0ba3e1e0fc02aa9ba'
 
@@ -282,7 +270,7 @@ class WebTest(TestCase):
     def test_one_playlist(self):
         '''operations with one playlist'''
 
-        folder = '/usr/share/radioweb/radio/fixtures/'
+        folder = os.path.join(CURPATH, 'fixtures/')
         newsongs = import_songs_from_folder(folder)
 
         self.assertTrue(len(newsongs)==2)
@@ -350,7 +338,7 @@ class WebTest(TestCase):
 
     def test_one_tag(self):
 
-        folder = '/usr/share/radioweb/radio/fixtures/'
+        folder = os.path.join(CURPATH, 'fixtures/')
         newsongs = import_songs_from_folder(folder)
 
         logging.info(u'imported songs errors: %s' % newsongs)
