@@ -11,19 +11,15 @@ from django.core.files.temp import NamedTemporaryFile
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.template import RequestContext
-from radioweb.radio.forms import *
-from radioweb.radio.models import *
 from django.contrib.auth.models import User, Group
 from django.contrib import messages
-from mutagen.oggvorbis import OggVorbisHeaderError
-from  radioweb.radio.utils import *
 from django.db.models import F
+from mutagen.oggvorbis import OggVorbisHeaderError
 
-from radioweb.radio import index 
-
-
-
-
+from liquidjango.forms import *
+from liquidjango.models import *
+from liquidjango.utils import *
+from liquidjango import index
 
 def get_total_time(songqueryset):
     from datetime import timedelta
@@ -32,8 +28,6 @@ def get_total_time(songqueryset):
     d = timedelta(seconds=int(totalmusictime))
     return str(d)
 
-
-
 def home(request):
     '''
     the homepage gives stats and action buttons for visitors
@@ -73,6 +67,7 @@ def home(request):
 					'data': data,
 					'onair': onair(),
 			},context_instance=RequestContext(request))
+
 def list_playlists():
     '''
     gets the available playlists in the server
@@ -107,17 +102,12 @@ def nextaudios(source):
     next = command_to_radio('%s.next' % source )
     return next.split("\n")
 
-
-
-
-
-
 def requests(request):
     '''
     To analize the playlist in the liquidsoap
 
     Functions:
-        * alive() from radio.utils:
+        * alive() from liquidjango.utils:
             takes the rids of the songs currently on liquidsoaps memory
         * get_requests(alive) from here
 
@@ -127,8 +117,6 @@ def requests(request):
     '''
     search_form = SearchForm()
     now =  alive()
-                  
-
 
     queue = get_requests(now) 
     playlists = {}
@@ -139,7 +127,7 @@ def requests(request):
 
     return render_to_response('requests.html', {
                     'search_form': search_form, 
-		    'onair': onair(),
+                    'onair': onair(),
                     'alive': now,
                     'playlists': playlists,
                     'queue': queue
@@ -151,7 +139,7 @@ def oneartist(request,object_id):
     A particular artist page
 
     All the info related to the artist. Soon will also have related artists and
-    tags, or other thngs that help to create a :model:`radio.Playlist`
+    tags, or other thngs that help to create a :model:`liquidjango.Playlist`
 
 
     **template**
@@ -664,7 +652,7 @@ def playonradio(request,object_id):
         song.plays = F('plays') + 1
         song.save()
 
-        play(song) #function on radio.utils.py
+        play(song) #function on liquidjango.utils.py
         messages.success(request, _('song submitted to the radio playlist. \
                      it will be played soon'))
 
@@ -698,7 +686,7 @@ def import_file(request):
 
     Importing options enforce terrible validation 
     for the archive to have some consistency.
-    Provided that the archive(:model:`radio.Song`) will be 
+    Provided that the archive(:model:`liquidjango.Song`) will be 
     streamed always in the same quality and format, 
     and that real time reencoding is a process we want 
     to spare our server of, we enforce the audio codec, 
